@@ -3,12 +3,16 @@ import requests
 import json
 import enum
 import zipfile
+import tarfile
 import os
+from multiprocessing import  Process, Pool
+import urllib.parse as path_encoder
 
 
 HELLO_WORLD_MESSAGE = 'Hello world! PyOhio Demo - 3! CLEpy'
 
-API_GW = "https://qe3b75sz3m.execute-api.us-east-2.amazonaws.com/api/"
+#API_GW = "https://qe3b75sz3m.execute-api.us-east-2.amazonaws.com/api/"
+API_GW = "https://csctis3kqa.execute-api.us-east-2.amazonaws.com/api/"
 
 def get_message():
     return HELLO_WORLD_MESSAGE
@@ -19,7 +23,7 @@ def print_hello_world():
 
 class FileType(enum.Enum):
     Train = 1
-    Test = 2
+    Weights= 2
     EntryPoint = 3
     Code = 4
     Inputs = 5
@@ -27,9 +31,10 @@ class FileType(enum.Enum):
     MNIST = 7
     processed = 8
     output = 9
+    Traindata =10
 
 
-def create_training_job(local_train_data, local_test_data, entry_point, inputs_folder, hyper_param):
+def create_training_job(local_data, source_code, weights, hyper_param):
 
     # create job id
 
@@ -38,20 +43,17 @@ def create_training_job(local_train_data, local_test_data, entry_point, inputs_f
 
     # upload data and code to s3
     # https://boto3.amazonaws.com/v1/documentation/api/latest/guide/s3-presigned-urls.html
-    if local_train_data is not None:
-        __upload_one_file_infolder(job_id, FileType.mnist.name, FileType.MNIST.name, FileType.processed.name, local_train_data)
-        print(f"upladed {local_train_data}")
+    if local_data is not None:
+        __upload_one_folder(job_id, FileType.Traindata.name, local_data)
+        print(f"upladed {local_data}")
 
-    if local_test_data is not None:
-        __upload_one_file_infolder(job_id, FileType.mnist.name, FileType.MNIST.name, FileType.processed.name, local_test_data)
-        print(f"upladed {local_test_data}")
+    if source_code is not None:
+        __upload_one_file(job_id, FileType.Code.name, source_code)
+        print(f"upladed {source_code}")
 
-    if entry_point is not None:
-        __upload_one_file(job_id, FileType.EntryPoint.name, entry_point)
-        print(f"upladed {entry_point}")
-
-    if inputs_folder is not None:
-        pass
+    if weights is not None:
+        __upload_one_file(job_id, FileType.Weights.name, weights)
+        print(f"upladed {weights}")
 
     # put hyper param to Dynamodb through API Gateway
     headers = {
@@ -66,14 +68,11 @@ def create_training_job(local_train_data, local_test_data, entry_point, inputs_f
 
     return job_id
 
-def folder_upload(jobid, rootDir): 
-    for lists in os.listdir(rootDir): 
-        path = os.path.join(rootDir, lists) 
-        #print path 
-        if os.path.isdir(path): 
-            folder_upload(jobid, path)
-        else:
-            __upload_one_file(jobid, FileType.Inputs.name, path)
+
+def make_tar(source_dir):
+    output_filename = os.path.basename(source_dir).split('.')[0] + ".tar"
+    with tarfile.open(output_filename, "w") as tar:
+        tar.add(source_dir, arcname=os.path.basename(source_dir))
 
 
 def get_training_job_status(job_id):
@@ -112,19 +111,34 @@ def cancel_training_job_status(job_id):
     """
     pass
 
-def get_zipfile(dirpath,outpath):
-	"""
-	zip file
-	:dirpath: source
-	:outpath: dest
-	"""
 
-	zip = zipfile.ZipFile(outpath, "w", zipfile.ZIP_STORED)
-	for path, dirnames, filenames in os.walk(dirpath):
-		fpath = path.replace(dirpath, '')
-		for filename in filenames:
-			zip.write(os.path.join(path, filename), os.path.join(fpath,filename))
-	zip.close()
+
+# upload folder
+def __upload_one_folder(job_id, type, dir_name: str):
+    file_list = __list_files(dir_name)
+    list_len = len(file_list)
+    workers = 100
+    worker_num = min(workers, 512)
+    worker_num = 1 if list_len < workers else worker_num
+    po = Pool(worker_num)
+    for f in file_list:
+        po.apply_async(func=__upload_one_file, args=(job_id, type, f))
+    po.close()
+    po.join()
+    
+
+
+def __list_files(dir_name):
+    r = []
+    subdirs = [x[0] for x in os.walk(dir_name)]
+    for subdir in subdirs:
+        files = os.walk(subdir).__next__()[2]
+        if (len(files) > 0):
+            for file in files:
+                r.append(os.path.join(subdir, file))
+    print(r)
+    return r
+
 
 
 
@@ -135,23 +149,8 @@ def get_zipfile(dirpath,outpath):
 def __upload_one_file(job_id, type, object_name):
 
     # request a s3 presigned URL
-    url = f"{API_GW}/s3url/{job_id}/{type}/{object_name}"
-    print(f"getting {url}")
-    response = requests.request("GET", url)
-    print(f"response {response}")
-    response_body = json.loads(response.text)
-
-
-    with open(object_name, 'rb') as f:
-        files = {'file': (object_name, f)}
-        http_response = requests.post(response_body['url'], data=response_body['fields'], files=files)
-    # If successful, returns HTTP status code 204
-    print(f'File upload HTTP status code: {http_response.status_code}')
-
-def __upload_one_file_infolder(job_id, type1, type2, type3, object_name):
-
-    # request a s3 presigned URL
-    url = f"{API_GW}/s3urlf/{job_id}/{type1}/{type2}/{type3}/{object_name}"
+    object_name_encoded = path_encoder.quote(object_name, safe="") # by default / is recognized as safe
+    url = f"{API_GW}/s3url/{job_id}/{type}/{object_name_encoded}"
     print(f"getting {url}")
     response = requests.request("GET", url)
     print(f"response {response}")
@@ -172,4 +171,16 @@ if __name__ == "__main__":
     #get_zipfile("./test","./test.zip")
     #folder_upload("test")
     #get_training_job_status("125cddd2-6686-44c2-8e14-1e4fe882ad94")
-    get_model("125cddd2-6686-44c2-8e14-1e4fe882ad94", "model.tar.gz")
\ No newline at end of file
+    #get_model("125cddd2-6686-44c2-8e14-1e4fe882ad94", "model.tar.gz")
+    
+    #__upload_one_file("repo", "source", "yolov5.tar")
+    #__upload_one_folder(uuid.uuid4(), "code", "/home/ubuntu/repo/intel_devcloud/yolov5")
+    #__upload_one_folder("repo", "test", "yolov5")
+    #r=[]
+    #__list_files("test")
+    #getFloderFiles("test")
+    #print(files)
+    make_tar("yolov5")
+    create_training_job("datasets_simple", "yolov5.tar", "yolov5s.pt", {"instance_type":"ml.m5.xlarge", "instance_count":"1", "framework_version":"1.8.1", "hyperparameters":{"imgsz":"64", "epochs":"4"}})
+    #make_tar("train.py")
+    #create_training_job("mnist", "train.tar", None, {"instance_type":"ml.m5.xlarge", "instance_count":"1", "framework_version":"1.8.1", "hyperparameters":{"epochs":"2","backend":"gloo", "hidden_channels":"2", "dropout":"0.2","kernel_size":"5", "optimizer":"sgd"}})
\ No newline at end of file
